@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017 - 2023 Avram Lubkin, All Rights Reserved
+# Copyright 2017 - 2025 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -93,8 +93,8 @@ class TestCounter(TestCase):
         counter.min_delta = 500
         counter.update()
         self.assertEqual(counter.output, [1, 2])
-        counter.min_delta = .01
-        time.sleep(.01)
+        counter.min_delta = 0.01
+        counter.last_update -= 0.01
         counter.update()
         self.assertEqual(counter.output, [1, 2, 4])
 
@@ -139,7 +139,7 @@ class TestCounter(TestCase):
         """
 
         ctr = self.ctr
-        ctr.start = time.time() - 5.0
+        ctr.start -= 5.0
         ctr._count_updated = ctr.start + 3.0
 
         self.assertEqual(int(ctr.elapsed), 5)
@@ -149,7 +149,7 @@ class TestCounter(TestCase):
         self.assertEqual(int(ctr.elapsed), 3)
 
         # Used last time count was updated when count equals total
-        ctr._closed = False
+        ctr._closed = 0.0
         ctr.count = ctr.total
         self.assertEqual(int(ctr.elapsed), 5)
 
@@ -162,7 +162,7 @@ class TestCounter(TestCase):
         self.ctr.refresh()
         self.assertRegex(self.manager.output[0],
                          r'write\(output=%s, flush=True, position=3\)' % self.output)
-        self.assertAlmostEqual(self.ctr.last_update, time.time(), delta=0.3)
+        self.assertAlmostEqual(self.ctr.last_update, self.ctr.start, delta=0.3)
 
         self.manager.output = []
         self.ctr.refresh(flush=False)
@@ -214,7 +214,7 @@ class TestCounter(TestCase):
         ctr = CounterDirect(stream=self.tty.stdout, total=100, desc='Test',
                             unit='ticks', series=SERIES_STD)
         self.assertIsInstance(ctr.manager, Manager)
-        ctr.start = time.time() - 50
+        ctr.start -= 50.0
         ctr.update(50, force=True)
 
         formatted = ctr.format()
@@ -232,7 +232,7 @@ class TestCounter(TestCase):
         Counter closing behavior
         """
 
-        manager = MockManager()
+        manager = MockManager(stream=self.tty.stdout)
 
         # Clear is False
         ctr = MockCounter(manager=manager, leave=False)
@@ -250,7 +250,7 @@ class TestCounter(TestCase):
             self.assertEqual(ctr.calls, [])
             self.assertEqual(manager.remove_calls, 2)
 
-        manager = MockManager()
+        manager = MockManager(stream=self.tty.stdout)
 
         # Clear is True, leave is True
         ctr = MockCounter(manager=manager, leave=True)
@@ -277,6 +277,23 @@ class TestCounter(TestCase):
 
         self.assertFalse(ctr in mgr.counters)
 
+    def test_reset(self):
+        """
+        Counter can be reset
+        """
+
+        ctr = self.ctr
+        ctr.start_count = 1
+        ctr.start -= 5.0
+        ctr._count_updated = ctr.start + 3.0
+        ctr.count = 9
+
+        ctr.reset()
+        self.assertAlmostEqual(ctr.start, time.time(), delta=0.1)
+        self.assertEqual(ctr.start, ctr._count_updated)
+        self.assertEqual(ctr.start, ctr.last_update)
+        self.assertEqual(ctr.count, 1)
+
 
 class TestCounterFormat(TestCase):
     """
@@ -297,7 +314,7 @@ class TestCounterFormat(TestCase):
 
         ctr = Counter(stream=self.tty.stdout, total=100, desc='Test',
                       unit='ticks', series=SERIES_STD, manager=self.manager)
-        ctr.start = time.time() - 50
+        ctr.start -= 50.0
         ctr.count = 50
 
         if PY2:
@@ -317,7 +334,7 @@ class TestCounterFormat(TestCase):
         ctr = Counter(stream=self.tty.stdout, manager=self.manager)
         self.assertRegex(ctr.format(width=80), r'0 \[00:0\d, 0.00/s\]')
         ctr.count = 50
-        ctr.start = time.time() - 50
+        ctr.start -= 50.0
         self.assertRegex(ctr.format(width=80), r'50 \[00:5\d, \d.\d\d/s\]')
 
         # With unit and description
@@ -326,7 +343,7 @@ class TestCounterFormat(TestCase):
         self.assertEqual(len(rtn), 80)
         self.assertRegex(rtn, r'Test 0 ticks \[00:0\d, 0.00 ticks/s\]')
         ctr.count = 50
-        ctr.start = time.time() - 50
+        ctr.start -= 50.0
         rtn = ctr.format(width=80)
         self.assertEqual(len(rtn), 80)
         self.assertRegex(rtn, r'Test 50 ticks \[00:5\d, \d.\d\d ticks/s\]')
@@ -340,7 +357,7 @@ class TestCounterFormat(TestCase):
             stream=self.tty.stdout, total=10, desc='Test', unit='ticks', manager=self.manager
         )
         ctr.count = 50
-        ctr.start = time.time() - 50
+        ctr.start -= 50.0
         rtn = ctr.format(width=80)
         self.assertEqual(len(rtn), 80)
         self.assertRegex(rtn, r'Test 50 ticks \[00:5\d, \d.\d\d ticks/s\]')
@@ -371,7 +388,7 @@ class TestCounterFormat(TestCase):
         ctr = Counter(stream=self.tty.stdout, total=10, desc='Test',
                       unit='ticks', series=SERIES_STD, manager=self.manager)
         ctr.count = 10
-        ctr.start = time.time() - 10
+        ctr.start -= 10.0
         formatted = ctr.format(width=80)
         self.assertEqual(len(formatted), 80)
         self.assertRegex(formatted,
