@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017 - 2023 Avram Lubkin, All Rights Reserved
+# Copyright 2017 - 2025 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -129,7 +129,7 @@ class TestManager(TestCase):
     def test_width(self):
         """Width hard-coded"""
 
-        manager = enlighten.Manager(width=100)
+        manager = enlighten.Manager(width=100, stream=self.tty.stdout)
         ctr = manager.counter(total=100)
 
         self.assertEqual(len(ctr.format()), 100)
@@ -377,7 +377,7 @@ class TestManager(TestCase):
         self.assertRegex(output, 'counter2.+counter1')
 
         # If auto-refreshed counter has been refreshed recently, skip
-        counter1.last_update = time.time() + 5
+        counter1.last_update = time.time() + 5.0
         counter2.refresh()
         self.tty.stdout.write(u'X\n')
         output = self.tty.stdread.readline()
@@ -459,7 +459,7 @@ class TestManager(TestCase):
 
         # Make sure nothing was flushed
         self.tty.stdout.write(u'X\n')
-        self.assertEqual(stdread.readline(), 'X\n')
+        self.assertEqual(stdread.readline(), term.u7 + 'X\n')
 
         # Run it again and make sure exit handling isn't reset
         del manager._buffer[:]
@@ -479,6 +479,27 @@ class TestManager(TestCase):
 
         self.assertEqual(manager.scroll_offset, 4)
 
+        # Ensure cursor is returned to previous position
+        del manager._buffer[:]
+        del manager._companion_buffer[:]
+        with mock.patch('enlighten._manager.atexit') as atexit:
+            with mock.patch('blessed.Terminal.get_location') as get_location:
+                get_location.return_value = (0, 3)
+                manager._set_scroll_area()
+
+        self.assertIn(term.move(scroll_position, 3), manager._buffer)
+
+        # Ensure on resize cursor is put at the start of the line
+        del manager._buffer[:]
+        del manager._companion_buffer[:]
+        manager.resize_lock = True
+        with mock.patch('enlighten._manager.atexit') as atexit:
+            with mock.patch('blessed.Terminal.get_location') as get_location:
+                get_location.return_value = (0, 3)
+                manager._set_scroll_area()
+
+        self.assertIn(term.move(scroll_position, 0), manager._buffer)
+
     def test_set_scroll_area_force(self):
         manager = enlighten.Manager(stream=self.tty.stdout, counter_class=MockCounter)
         manager.counters['dummy'] = 3
@@ -568,7 +589,7 @@ class TestManager(TestCase):
 
         # No output, No changes
         self.tty.stdout.write(u'X\n')
-        self.assertEqual(self.tty.stdread.readline(), 'X\n')
+        self.assertEqual(self.tty.stdread.readline(), term.u7 + 'X\n')
         self.assertEqual(signal.getsignal(signal.SIGWINCH), manager._stage_resize)
         self.assertTrue(manager.process_exit)
 
@@ -798,7 +819,7 @@ class TestManager(TestCase):
         manager = enlighten.Manager(stream=self.tty.stdout, counter_class=MockCounter,
                                     threaded=True)
         counter3 = MockCounter(manager=manager)
-        counter3.last_update = time.time()
+        counter3.last_update = counter3.start
         manager.counters[counter3] = 3
         manager.scroll_offset = 4
         term = manager.term
